package org.apache.fulcrum.security.torque.om;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.torque.Column;
import org.apache.torque.TorqueException;
import org.apache.torque.criteria.CriteriaInterface;
import org.apache.torque.om.mapper.RecordMapper;


/**
 * Maps ResultSet rows into TorqueDynamicUser objects.
 *
 * The skeleton for this class was autogenerated by Torque on:
 *
 * [Sun Jul 19 20:59:08 CEST 2015]
 *
 */
public class BaseTorqueDynamicUserRecordMapper implements RecordMapper<TorqueDynamicUser>
{

    /** The class log. */
    private static Log log
            = LogFactory.getLog(BaseTorqueDynamicUserRecordMapper.class);

    /**
     * Constructs the object from the current row in the resultSet.
     *
     * @param resultSet the resultSet to operate on, already pointing
     *        to the correct row. Not null.
     * @param a possible offset in the columns to be considered
     *        (if previous columns contain other objects),
     *        or 0 for no offset.
     * @param criteria The criteria which created the result set.
     *        If set, the attributes to set in the data object
     *        are determined from the select columns in the criteria;
     *        if no matching column can be found, null is returned.
     *        If not set, all of the table's columns are read from the
     *        result set in the order defined in the table definition.
     *
     * @return the mapped object, not null.
     *
     * @throws TorqueException when reading fields from the RecordSet fails
     *         or if a Criteria is passed which contains select columns other
     *         than the columns in the FULCRUM_DYNAMIC_USER table.
     */
    public TorqueDynamicUser processRow(
                ResultSet resultSet,
                int offset,
                CriteriaInterface<?> criteria)
            throws TorqueException
    {
        TorqueDynamicUser torqueDynamicUser = new TorqueDynamicUser();

        try 
        {
            torqueDynamicUser.setLoading(true);
            if (criteria == null)
            {
                torqueDynamicUser.setEntityId(
                        getEntityId(resultSet, offset + 1));
                torqueDynamicUser.setEntityName(
                        getEntityName(resultSet, offset + 2));
                torqueDynamicUser.setPassword(
                        getPassword(resultSet, offset + 3));
            }
            else
            {
                // try to get columns to be mapped
                // from criteria's select columns
                boolean columnMapped = false;
                int totalOffset = offset + 1;
                List<Column> selectColumns = criteria.getSelectColumns();
                List<Column> columnsWithoutOffset = selectColumns.subList(
                        offset, 
                        selectColumns.size());
                for (Column column : columnsWithoutOffset)
                {
                    if (BaseTorqueDynamicUserPeer.USER_ID.getSqlExpression().equals(
                            column.getSqlExpression()))
                    {
                        torqueDynamicUser.setEntityId(
                            getEntityId(resultSet, totalOffset));
                        columnMapped = true;
                    }
                    else if (BaseTorqueDynamicUserPeer.LOGIN_NAME.getSqlExpression().equals(
                            column.getSqlExpression()))
                    {
                        torqueDynamicUser.setEntityName(
                            getEntityName(resultSet, totalOffset));
                        columnMapped = true;
                    }
                    else if (BaseTorqueDynamicUserPeer.PASSWORD_VALUE.getSqlExpression().equals(
                            column.getSqlExpression()))
                    {
                        torqueDynamicUser.setPassword(
                            getPassword(resultSet, totalOffset));
                        columnMapped = true;
                    }
                    totalOffset++;
                }
                if (!columnMapped)
                {
                    log.debug("no columns to map found in criteria, "
                        + "returning null");
                    return null;
                }
            }
            torqueDynamicUser.setNew(false);
            torqueDynamicUser.setModified(false);
        }
        finally
        {
            torqueDynamicUser.setLoading(false);
        }
        return torqueDynamicUser;
    }

        /**
         * Reads the value of the <code>columnIndex</code>'th column
         * in the <code>resultSet</code> so that it can be used to set
         * the field entityId in TorqueDynamicUser.
         *
         * @param dbObject the database object to fill, not null.
         * @param resultSet the ResultSet to read from, not null.
         * @param columnIndex the index in the resultSet which should be read.
         *
         * @return the content of the column.
         *
         * @throws SQLException if a problem occurs when reading
         *         from the resultSet.
         */
        protected Integer getEntityId(
                    ResultSet resultSet,
                    int columnIndex)
                throws TorqueException
        {
            try
            {
                Integer value = resultSet.getInt(columnIndex);
                if (resultSet.wasNull())
                {
                    value = null;
                }
                return value;
            }
            catch (SQLException e)
            {
                throw new TorqueException(e);
            }
        }

        /**
         * Reads the value of the <code>columnIndex</code>'th column
         * in the <code>resultSet</code> so that it can be used to set
         * the field entityName in TorqueDynamicUser.
         *
         * @param dbObject the database object to fill, not null.
         * @param resultSet the ResultSet to read from, not null.
         * @param columnIndex the index in the resultSet which should be read.
         *
         * @return the content of the column.
         *
         * @throws SQLException if a problem occurs when reading
         *         from the resultSet.
         */
        protected String getEntityName(
                    ResultSet resultSet,
                    int columnIndex)
                throws TorqueException
        {
            try
            {
                return resultSet.getString(columnIndex);
            }
            catch (SQLException e)
            {
                throw new TorqueException(e);
            }
        }

        /**
         * Reads the value of the <code>columnIndex</code>'th column
         * in the <code>resultSet</code> so that it can be used to set
         * the field password in TorqueDynamicUser.
         *
         * @param dbObject the database object to fill, not null.
         * @param resultSet the ResultSet to read from, not null.
         * @param columnIndex the index in the resultSet which should be read.
         *
         * @return the content of the column.
         *
         * @throws SQLException if a problem occurs when reading
         *         from the resultSet.
         */
        protected String getPassword(
                    ResultSet resultSet,
                    int columnIndex)
                throws TorqueException
        {
            try
            {
                return resultSet.getString(columnIndex);
            }
            catch (SQLException e)
            {
                throw new TorqueException(e);
            }
        }


}
